Generate a new point using LRPS
Source:R/lrps-class.R, R/multi_ellipsoid.R, R/rwmh_cube.R, and 3 more
propose.RdUse an LRPS method to replace points within the live set during a nested
sampling run. This method must be implemented on all classes that inherit
from ernest_lrps.
Usage
propose(x, original = NULL, criterion = -Inf)
# S3 method for class 'multi_ellipsoid'
propose(x, original = NULL, criterion = -Inf)
# S3 method for class 'rwmh_cube'
propose(x, original = NULL, criterion = -Inf)
# S3 method for class 'slice_rectangle'
propose(x, original = NULL, criterion = -Inf)
# S3 method for class 'unif_cube'
propose(x, original = NULL, criterion = -Inf)
# S3 method for class 'unif_ellipsoid'
propose(x, original = NULL, criterion = -Inf)Arguments
- x
[ernest_lrps]
A likelihood-restricted prior sampler.- original
[double(x$n_dim)]
A parameter vector which can be used to start the proposal process. Optional; ifNULLproposals are generated from sampling the unconstrained unit cube.- criterion
[double(1)]
A log-likelihood value that restricts the region of prior space to sample from.
Value
[list], containing at least these named elements:
unit:[double(x$n_dim)]The replacement point, expressed in the unit-cube.log_lik:[double(1)]The log-likelihood value atunit.neval:[integer(1)]The number of evaluations ofunit_log_fnneeded to generateunit. Do not confuse this with the number of samples evaluated during the call topropose, asunit_log_fnmay be capable of evaluating multiple parameters with a single call.