Use rejection sampling across the entire prior distribution to create new samples. This is highly inefficient as an LRPS, but may be useful for testing the behaviour of a nested sampling specification.
Value
[unif_cube], a named list that inherits from [ernest_lrps].
References
Speagle, J. S. (2020). Dynesty: A Dynamic Nested Sampling Package for Estimating Bayesian Posteriors and Evidences. Monthly Notices of the Royal Astronomical Society, 493, 3132–3158. doi:10.1093/mnras/staa278
See also
Other ernest_lrps:
multi_ellipsoid(),
rwmh_cube(),
slice_rectangle(),
unif_ellipsoid()
Examples
data(example_run)
lrps <- unif_cube()
ernest_sampler(example_run$log_lik_fn, example_run$prior, sampler = lrps)
#> Nested sampling run specification:
#> * No. points: 500
#> * Sampling method: Uniform unit cube sampling
#> * Prior: uniform prior distribution with 3 dimensions (x, y, and z)